Module format

Module format 

Functions

amount
bytes
concise_duration
Formats duration approximately, with a unit (SI units, days, weeks), using the shortest possible representation with up to one fractional digit.
exact_bytes
A counterpart of parsing::exact_bytes that produces the string from which the exact same size can be parsed.
exact_duration
A counterpart of parsing::exact_duration that produces the string from which the exact same duration can be parsed.
gas
hash
Hex-formatted hash without truncation.
percent
slot
slot_time
units
Returns an approximate representation of quantity n measured in units ones using prefix notation.