cores

Function cores 

pub fn cores(s: &str) -> Result<VecSet<CoreIndex>>
Parse comma-separated list of cores or core ranges: “1,2,4-6,10”. Ranges are inclusive.

NOTE This function doesn’t check if core indices are correct since the protocol parameters might haven’t been initialized at the time of command line arguments parsing.