Functions
- amount
- bytes
- concise_
duration - Formats duration approximately, with a unit (SI units, days, weeks), using the shortest possible representation with up to one fractional digit.
- exact_
bytes - A counterpart of parsing::exact_bytes that produces the string from which the exact same size can be parsed.
- exact_
duration - A counterpart of parsing::exact_duration that produces the string from which the exact same duration can be parsed.
- gas
- hash
- Hex-formatted hash without truncation.
- percent
- slot
- slot_
time - units
- Returns an approximate representation of quantity
nmeasured in unitsonesusing prefix notation.